screed -- short read sequence utils in Python.

The official central repository for screed is:

   https://github.com/ged-lab/screed

See http://readthedocs.org/docs/screed/en/latest/ for docs.

Issues are tracked at https://github.com/ged-lab/khmer/issues.

[![Build Status](http://ci.ged.msu.edu/job/screed/badge/icon)](http://ci.ged.msu.edu/job/screed/)
